@@ -19,10 +19,15 @@
 #' Enter \code{TRUE} to check the Shapley values adjusted based on the model's average contribution.
 #' @param plot.flag If \code{average = "obs"}, the quantile interval of each variable's is provided by default.
 #' @param probs Enter the probability for the quantile interval. The default value is \code{0.95}.
+#' @param xlab  Enter the label to be displayed on the x-axis. If not provided, a default label will be used.
+#' @param ylab Enter the label for the y-axis if needed.
 #' @param ... Additional arguments to be passed
 #' @return The plot is returned based on the specified option.: 
-#' \item{out}{If average is \code{"obs"} or \code{"post"}, a bar plot or summary plot is generated based on the selected averaging criterion. If average is `"both"`, a boxplot is displayed to
-#'show the distribution of Shapley values computed using both criteria. If adjust is \code{TRUE}, the adjusted Shapley values are displayed.
+#' \item{out}{If average is \code{"obs"} or \code{"post"}, a bar plot or summary plot is generated based on the selected averaging criterion. 
+#' When \code{average} is set to \code{"both"}, either a bar plot or a boxplot comparing the distributions of Shapley values computed under the two averaging criteria is generated.
+#' In the case where a boxplot is produced, the observation-based and posterior-sample-based summaries can additionally be rendered separately
+#' via \code{out$observation} and \code{out$post}, respectively.
+#' If adjust is \code{TRUE}, the adjusted Shapley values are displayed.
 #' If \code{num_post} is specified, a bar plot or summary plot for the selected posterior sample is generated.}
 #' @examples
 #' \donttest{
@@ -69,18 +74,29 @@
 #' @export
 
 plot.ExplainBART <- function(x, average=NULL, type=NULL, num_post=NULL,
-                             plot.flag=TRUE, adjust=FALSE, probs=0.95, title=NULL,...){
+                             plot.flag=TRUE, adjust=FALSE, probs=0.95, 
+                             title=NULL,xlab=NULL, ylab=NULL,...){
  
   
-  if (!inherits(x, "ExplainBART") ) {
-    message("The input object must be of class 'ExplainBART'.")
+  if (!inherits(x, c("ExplainBART", "ExplainbartMachine")) ) {
+    message("The input object must be of class 'ExplainBART' or 'ExplainbartMachine'.")
     return(invisible(NULL))
   } else if (missing(x) ) {
     stop("The object containing the Shapley values of models obtained from the 'Explain' function is missing.")
     return(invisible(NULL))
   }
   
-   object <- x 
+  if (is.null(xlab)) { 
+    y_text <- if (!is.null(type) && type == "bees") {
+      "SHAP (Impact on model output)"
+    } else {
+      "Importance"
+    }} else { 
+      y_text = xlab 
+    }
+  if (is.null(ylab)){x_text =""} else {x_text = ylab}
+  
+  object <- x 
   value <- variable <- n <- Average_re <-  0 
   feature_names <- names(object$newdata)
   factor_names <- object$factor_names
@@ -147,7 +163,7 @@ plot.ExplainBART <- function(x, average=NULL, type=NULL, num_post=NULL,
 
       sample_summary$percent <- paste0(sprintf("%.1f", round(sample_summary$zero/sample_summary$n*100, 1)) ,"%")
 
-      out <- bar_plot(Local_mean,probs = NULL, plot.flag = FALSE , title)
+      out <- bar_plot(Local_mean,probs = NULL, plot.flag = FALSE , title, x_text, y_text)
 
       ymin <- (- diff(range(out$coordinates$limits$y,na.rm = TRUE)) * 0.02)
 
@@ -158,7 +174,7 @@ plot.ExplainBART <- function(x, average=NULL, type=NULL, num_post=NULL,
 
     } else if (isTRUE( type == "bees")){
       #  summary plot
-      out <- summary_plot (local_obs,title )
+      out <- summary_plot (local_obs,title,  x_text, y_text)
       print(out)
 }
 
@@ -180,7 +196,7 @@ plot.ExplainBART <- function(x, average=NULL, type=NULL, num_post=NULL,
       colnames(obs_mean_shap) <- names(object$phis)
 
 
-      out <- bar_plot (obs_mean_shap, probs, plot.flag= T,title )
+      out <- bar_plot (obs_mean_shap, probs, plot.flag= T,title, x_text, y_text)
 
       if ( isTRUE(type =="bees") ) {
         message("In Average based on observation,\n a barplot is also provided by entering type='bees'.")
@@ -226,7 +242,7 @@ plot.ExplainBART <- function(x, average=NULL, type=NULL, num_post=NULL,
 
         sample_summary$percent <- paste0(sprintf("%.1f", round(sample_summary$zero/sample_summary$n*100, 1)) ,"%")
 
-        out <- bar_plot (Local_mean, probs = NULL, plot.flag = FALSE,title)
+        out <- bar_plot (Local_mean, probs = NULL, plot.flag = FALSE,title, x_text, y_text)
         ymin <- (- diff(range(out$coordinates$limits$y,na.rm = TRUE)) * 0.02)
 
         out <- out +
@@ -237,7 +253,7 @@ plot.ExplainBART <- function(x, average=NULL, type=NULL, num_post=NULL,
 
       } else if (isTRUE(type == "bees")){
         #  summary plot
-         out <- summary_plot (local_total,title)
+         out <- summary_plot (local_total,title, x_text, y_text)
         print (out)
 
       }
@@ -261,12 +277,12 @@ plot.ExplainBART <- function(x, average=NULL, type=NULL, num_post=NULL,
 
       if (isTRUE(type == "bees") | is.null (type)){
         # Local SHAP summary plot - i th posterior
-        out <- summary_plot (local_obs ,title)
+        out <- summary_plot (local_obs ,title, x_text, y_text)
          annotate_figure(out, top = text_grob(paste0("Sample number = ", num_post),
                                                                      hjust = 1, x = 0.95,vjust = 1.05, size = 10 ))
       } else if (isTRUE(type == "bar")) {
 
-        out <- bar_plot (abs(obs), probs =NULL, plot.flag = FALSE,title )
+        out <- bar_plot (abs(obs), probs =NULL, plot.flag = FALSE,title, x_text, y_text )
 
         sample_summary <- local_obs$long %>% filter (is.na (value)==FALSE)%>%
           select(c("variable", "value"))%>% group_by(variable) %>% mutate (n=n()) %>%
@@ -360,7 +376,7 @@ plot.ExplainBART <- function(x, average=NULL, type=NULL, num_post=NULL,
       left_p <-  data_list$total_long %>% filter (is.na(value)==FALSE & Average_re=="Observation")%>%
         ggplot( aes(x= variable, y=value, fill= Average_re )) +
         geom_boxplot() +coord_flip() + theme_bw(base_size = 11) +
-        labs(fill = "", x="",y="Mean(|SHAP|)") +
+        labs(fill = "", x=x_text,y=y_text) +
         scale_x_discrete(limits = rev(obs_variable),
                          labels = rev(obs_variable))+
         scale_fill_manual(values=c("#F8766D"))+
@@ -382,7 +398,7 @@ plot.ExplainBART <- function(x, average=NULL, type=NULL, num_post=NULL,
       right_p <-  data_list$total_long %>% filter (is.na(value)==FALSE & Average_re=="Samples")%>%
         ggplot( aes(x = variable, y = value, fill = Average_re)) +
         geom_boxplot() + coord_flip() + theme_bw(base_size = 11) +
-        labs(fill = "", x="",y="Mean(|SHAP|)") +
+        labs(fill = "", x=x_text,y=y_text) +
         scale_x_discrete(limits = rev(obs_variable),
                          labels = rev(obs_variable))+
         scale_fill_manual(values=c( "#00BFC4"))+
@@ -393,17 +409,25 @@ plot.ExplainBART <- function(x, average=NULL, type=NULL, num_post=NULL,
                                   hjust = 1, label = sample_summary$percent, size = 2.5)
 
 
-      grid.arrange(left_p, right_p, ncol= 1, top= textGrob(title, x = 0.2, hjust = 0)  )
-
+      out <- list(
+        combined = gridExtra::arrangeGrob(left_p, right_p, ncol = 1,
+                               top = textGrob(title, x = 0.2, hjust = 0)),
+        observation = left_p,
+        post = right_p
+      )
+      grid::grid.draw(out$combined)
+      return(invisible(out))
+      
       if (isTRUE(type =="bees")) {
         message("In Average = 'both',\n a baxplot is also provided by entering type='bees'.")
       }
 
     } else if (isTRUE(type == "bar")){
+      
       out <- ggplot( data_list$mean_data, aes(x= variable, y= mean, fill = Average_re )) +
         geom_bar( stat = "identity" , position="dodge") +coord_flip() + theme_bw(base_size = 11) +
         scale_fill_manual(values=c( "#00BFC4","#F8766D"))+
-        labs(fill = "Criteria for average ", x="",y="Mean(|SHAP|)") +
+        labs(fill = "Criteria for average ", x=x_text,y=y_text) +
         scale_x_discrete(limits = rev(obs_variable), labels = rev(obs_variable)) +
         ylim(c(0,max(data_list$mean_data$mean)))+
         geom_text(aes(label = sprintf("%.3f",round(mean,3))),
